@@ -1,10 +1,14 @@
-from flask_jwt_extended import get_current_user
 from flask_jwt_extended import (
-    JWTManager, jwt_required, get_jwt_identity,
-    create_access_token, create_refresh_token,
-    jwt_refresh_token_required, get_raw_jwt
+    JWTManager,
+    get_raw_jwt,
+    jwt_required,
+    get_jwt_manager,
+    get_current_user,
+    get_jwt_identity,
+    create_access_token,
+    create_refresh_token,
+    jwt_refresh_token_required
 )
-from flask_jwt_extended.internal_utils import get_jwt_manager
 
 from python_helper import Constant as c
 from python_helper import log, Function
